@@ -1,5 +1,7 @@
 """
-Main interface for amp service literal definitions.
+Type annotations for amp service literal definitions.
+
+[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_amp/literals.html)
 
 Usage::
 
